import React, { useState } from 'react';
import AppBar from '@mui/material/AppBar';
import Box from '@mui/material/Box';
import Toolbar from '@mui/material/Toolbar';
import IconButton from '@mui/material/IconButton';
import Typography from '@mui/material/Typography';
import Menu from '@mui/material/Menu';
import MenuItem from '@mui/material/MenuItem';
import MenuIcon from '@mui/icons-material/Menu';
import Container from '@mui/material/Container';
import Avatar from '@mui/material/Avatar';
import Tooltip from '@mui/material/Tooltip';
import { Button } from '@mui/material';
import logo from '../assets/icons/psi_01_sn.svg';
import '../App.css';
import { Shipment, Dewar, ContactPerson, Address, Proposal } from '../types.ts'; // Import types from a single statement
import ShipmentView from './ShipmentView.tsx';
import PlanningView from './PlanningView.tsx';

const pages = ['Validator', 'Shipments', 'Samples', 'Planning', 'Experiments', 'Results', 'Docs'];

const ResponsiveAppBar: React.FC = () => {
    const [anchorElNav, setAnchorElNav] = useState<null | HTMLElement>(null);
    const [anchorElUser, setAnchorElUser] = useState<null | HTMLElement>(null);
    const [selectedPage, setSelectedPage] = useState<string>('Shipments');
    const [newShipment, setNewShipment] = useState<Shipment>({
        shipment_id: '',
        shipment_name: '',
        shipment_status: '',
        number_of_dewars: 0,
        shipment_date: '',
        return_address: [], // Correctly initialize return_address
        contact_person: null, // Use null
        dewars: [],
    });
    const [isCreatingShipment, setIsCreatingShipment] = useState(false);
    const [selectedShipment, setSelectedShipment] = useState<Shipment | null>(null);
    const [selectedDewar, setSelectedDewar] = useState<Dewar | null>(null);

    // Define missing state variables for contacts, addresses, and proposals
    const [contactPersons, setContactPersons] = useState<ContactPerson[]>([]);
    const [returnAddresses, setReturnAddresses] = useState<Address[]>([]);
    const [proposals, setProposals] = useState<Proposal[]>([]);

    const handleOpenNavMenu = (event: React.MouseEvent<HTMLElement>) => {
        setAnchorElNav(event.currentTarget);
    };

    const handleCloseNavMenu = () => {
        setAnchorElNav(null);
    };

    const handlePageClick = (page: string) => {
        setSelectedPage(page);
        handleCloseNavMenu();
    };

    const handleOpenUserMenu = (event: React.MouseEvent<HTMLElement>) => {
        setAnchorElUser(event.currentTarget);
    };

    const handleCloseUserMenu = () => {
        setAnchorElUser(null);
    };

    // Updated selectShipment to accept Shipment | null
    const selectShipment = (shipment: Shipment | null) => {
        setSelectedShipment(shipment);
        setIsCreatingShipment(false);
        setSelectedDewar(null);
    };

    const handleSaveShipment = () => {
        console.log('Saving shipment:', newShipment);
        setIsCreatingShipment(false);
        setNewShipment({
            shipment_id: '',
            shipment_name: '',
            shipment_status: '',
            number_of_dewars: 0,
            shipment_date: '',
            return_address: [], // Add return_address to the reset state
            contact_person: null, // Use null
            dewars: [],
        });
    };

    return (
        <div>
            <AppBar position="static" sx={{ backgroundColor: '#2F4858' }}>
                <Container maxWidth="xl">
                    <Toolbar disableGutters>
                        <a className="nav" href="">
                            <img src={logo} height="50px" alt="PSI logo" />
                        </a>
                        <Typography
                            variant="h6"
                            noWrap
                            component="a"
                            href="#app-bar-with-responsive-menu"
                            sx={{
                                mr: 2,
                                display: { xs: 'none', md: 'flex' },
                                fontFamily: 'monospace',
                                fontWeight: 300,
                                color: 'inherit',
                                textDecoration: 'none',
                            }}
                        >
                            Heidi v2
                        </Typography>
                        <Box sx={{ flexGrow: 1, display: { xs: 'flex', md: 'none' } }}>
                            <IconButton
                                size="large"
                                aria-label="menu"
                                onClick={handleOpenNavMenu}
                                color="inherit"
                            >
                                <MenuIcon />
                            </IconButton>
                            <Menu
                                id="menu-appbar"
                                anchorEl={anchorElNav}
                                anchorOrigin={{
                                    vertical: 'bottom',
                                    horizontal: 'left',
                                }}
                                keepMounted
                                transformOrigin={{
                                    vertical: 'top',
                                    horizontal: 'left',
                                }}
                                open={Boolean(anchorElNav)}
                                onClose={handleCloseNavMenu}
                            >
                                {pages.map((page) => (
                                    <MenuItem key={page} onClick={() => handlePageClick(page)}>
                                        {page}
                                    </MenuItem>
                                ))}
                            </Menu>
                        </Box>
                        <Box sx={{ flexGrow: 1, display: { xs: 'none', md: 'flex' } }}>
                            {pages.map((page) => (
                                <Button
                                    key={page}
                                    onClick={() => handlePageClick(page)}
                                    sx={{ my: 2, color: 'white', display: 'block', fontSize: '1rem', padding: '12px 24px' }}
                                >
                                    {page}
                                </Button>
                            ))}
                        </Box>
                        <Box sx={{ flexGrow: 0 }}>
                            <Tooltip title="Open settings">
                                <IconButton onClick={handleOpenUserMenu} sx={{ p: 0 }}>
                                    <Avatar />
                                </IconButton>
                            </Tooltip>
                            <Menu
                                sx={{ mt: '45px' }}
                                id="menu-appbar"
                                anchorEl={anchorElUser}
                                anchorOrigin={{
                                    vertical: 'top',
                                    horizontal: 'right',
                                }}
                                keepMounted
                                transformOrigin={{
                                    vertical: 'top',
                                    horizontal: 'right',
                                }}
                                open={Boolean(anchorElUser)}
                                onClose={handleCloseUserMenu}
                            >
                                <MenuItem onClick={handleCloseUserMenu}>DUO</MenuItem>
                                <MenuItem onClick={handleCloseUserMenu}>Logout</MenuItem>
                            </Menu>
                        </Box>
                    </Toolbar>
                </Container>
            </AppBar>
            <Box sx={{ width: '100%', borderRight: '1px solid #ccc', padding: 2 }}>
                {selectedPage === 'Shipments' && (
                    <ShipmentView
                        newShipment={newShipment}
                        setNewShipment={setNewShipment}
                        isCreatingShipment={isCreatingShipment}
                        setIsCreatingShipment={setIsCreatingShipment}
                        selectedShipment={selectedShipment}
                        selectShipment={selectShipment} // Now accepts Shipment | null
                        selectedDewar={selectedDewar}
                        setSelectedDewar={setSelectedDewar}
                        handleSaveShipment={handleSaveShipment}
                        contactPersons={contactPersons}
                        returnAddresses={returnAddresses}
                        proposals={proposals}
                    />
                )}
                {selectedPage === 'Planning' && <PlanningView />}
            </Box>
        </div>
    );
};

export default ResponsiveAppBar;
